pype32.datatypes

Package pype32 :: Module datatypes |
[hide private]
[frames] | no frames]

# Module datatypes

source code

Data types objects.

Classes | [hide private]
Strings
| String String object.
| AlignedString Aligned string object.
Native
| Array Array object.
| BYTE Byte object.
| WORD Word object.
| DWORD Dword object.
| QWORD Qword object.

Variables | [hide private]
| __revision__ = ``'``$Id$``'``
| TYPE_QWORD = `4274716362`
| TYPE_DWORD = `3735928559`
| TYPE_WORD = `3405695742`
| TYPE_BYTE = `12586990`
| TYPE_ARRAY = `65226`
| UNKNOWN_ARRAY_TYPE = `65535`
| __package__ = ``'``pype32``'``